@@ -3,4 +3,4 @@ import os
 from .clock import Clock
 from .fileio import ReadFile, WriteFile
 from .input import Input
-from .strings import Length
+from .strings import StringDataType
